==> kubernetes-model-1.0.43-sources.jar: io/fabric8/openshift/api/model/DoneableOAuthClientAuthorizationList.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DoneableOAuthClientAuthorizationList extends OAuthClientAuthorizationListFluentImpl<DoneableOAuthClientAuthorizationList> implements Doneable<OAuthClientAuthorizationList>, OAuthClientAuthorizationListFluent<DoneableOAuthClientAuthorizationList>{


    private final OAuthClientAuthorizationListBuilder builder;    private final Function<OAuthClientAuthorizationList, OAuthClientAuthorizationList> function;
    public DoneableOAuthClientAuthorizationList ( Function<OAuthClientAuthorizationList, OAuthClientAuthorizationList> function){
    this.builder=new OAuthClientAuthorizationListBuilder(this);this.function=function;
}
    public DoneableOAuthClientAuthorizationList ( OAuthClientAuthorizationList item,  Function<OAuthClientAuthorizationList, OAuthClientAuthorizationList> function){
    this.builder=new OAuthClientAuthorizationListBuilder(this, item);this.function=function;
}
    public DoneableOAuthClientAuthorizationList ( OAuthClientAuthorizationList item){
    this.builder=new OAuthClientAuthorizationListBuilder(this, item);this.function=new Function<OAuthClientAuthorizationList, OAuthClientAuthorizationList>() {
    public OAuthClientAuthorizationList apply(OAuthClientAuthorizationList item) {
        return item;
    }
}
;
}

    public OAuthClientAuthorizationList done(){
     return function.apply(builder.build());
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/openshift/api/model/DoneableOAuthClientAuthorizationList.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.KubernetesResourceList;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DoneableOAuthClientAuthorizationList extends OAuthClientAuthorizationListFluentImpl<DoneableOAuthClientAuthorizationList> implements Doneable<OAuthClientAuthorizationList>,OAuthClientAuthorizationListFluent<DoneableOAuthClientAuthorizationList>{


    private final OAuthClientAuthorizationListBuilder builder;    private final Function<OAuthClientAuthorizationList, OAuthClientAuthorizationList> function;
    public DoneableOAuthClientAuthorizationList ( Function<OAuthClientAuthorizationList, OAuthClientAuthorizationList> function){
    this.builder=new OAuthClientAuthorizationListBuilder(this);this.function=function;
}
    public DoneableOAuthClientAuthorizationList ( OAuthClientAuthorizationList item,  Function<OAuthClientAuthorizationList, OAuthClientAuthorizationList> function){
    this.builder=new OAuthClientAuthorizationListBuilder(this);this.function=function;
}
    public DoneableOAuthClientAuthorizationList ( OAuthClientAuthorizationList item){
    this.builder=new OAuthClientAuthorizationListBuilder(this, item);this.function=new Function<OAuthClientAuthorizationList, OAuthClientAuthorizationList>() {
    public OAuthClientAuthorizationList apply(OAuthClientAuthorizationList item) {
        return item;
    }
}
;
}

    public OAuthClientAuthorizationList done(){
     return function.apply(builder.build());
}


}
